import os
from setuptools import setup, find_packages
from setuptools.extension import Extension
from Cython.Build import cythonize


def get_long_desciption():
    cwd = os.path.abspath(os.path.dirname(__file__))
    filename = os.path.join(cwd, "README.md")
    with open(filename) as f:
        long_description = f.read()

    return long_description


def get_version():
    version = None

    with open("src/pcre2/__init__.py") as file:
        for line in file:
            if line.startswith("__version__"):
                return line.split()[-1].strip().strip('"')

    return os.getenv("RPM_PACKAGE_VERSION", "0.0.0")


setup(
    name="pcre2",
    version=get_version(),
    description="Python bindings for the PCRE2 regular expression library",
    long_description=get_long_desciption(),
    long_description_content_type="text/markdown",
    license="BSD 3-Clause License",
    author="Garrett Tetrault",
    url="https://github.com/grtetrault/pcre2.py",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: C",
        "Programming Language :: Cython",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX :: Linux",
        "Operating System :: Microsoft :: Windows",
    ],
    include_package_data=True,
    packages=find_packages("src"),
    package_dir={"": "src"},
    ext_modules=cythonize(
        Extension(
            "*",
            ["src/pcre2/*.pyx"],
            extra_compile_args=["-DPCRE2_CODE_UNIT_WIDTH=8"],
            extra_link_args=["-lpcre2-8"],
        ),
        language_level=2,
    ),
)
